==> huaweicloudsdkdms-3.0.62-py2.py3-none-any.whl: huaweicloudsdkdms/v2/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import DmsClient
from huaweicloudsdkdms.v2.dms_client import DmsClient
from huaweicloudsdkdms.v2.dms_async_client import DmsAsyncClient
# import models into sdk package
from huaweicloudsdkdms.v2.model.batch_create_or_delete_queue_tag_request import BatchCreateOrDeleteQueueTagRequest
from huaweicloudsdkdms.v2.model.batch_create_or_delete_queue_tag_response import BatchCreateOrDeleteQueueTagResponse
from huaweicloudsdkdms.v2.model.batch_create_or_delete_tag_req import BatchCreateOrDeleteTagReq
from huaweicloudsdkdms.v2.model.batch_create_or_delete_tag_req_tags import BatchCreateOrDeleteTagReqTags
from huaweicloudsdkdms.v2.model.confirm_consumption_messages_req import ConfirmConsumptionMessagesReq
from huaweicloudsdkdms.v2.model.confirm_consumption_messages_request import ConfirmConsumptionMessagesRequest
from huaweicloudsdkdms.v2.model.confirm_consumption_messages_response import ConfirmConsumptionMessagesResponse
from huaweicloudsdkdms.v2.model.confirm_dead_letters_messages_req import ConfirmDeadLettersMessagesReq
from huaweicloudsdkdms.v2.model.confirm_dead_letters_messages_req_message import ConfirmDeadLettersMessagesReqMessage
from huaweicloudsdkdms.v2.model.confirm_dead_letters_messages_request import ConfirmDeadLettersMessagesRequest
from huaweicloudsdkdms.v2.model.confirm_dead_letters_messages_response import ConfirmDeadLettersMessagesResponse
from huaweicloudsdkdms.v2.model.consume_deadletters_message import ConsumeDeadlettersMessage
from huaweicloudsdkdms.v2.model.consume_deadletters_message_message import ConsumeDeadlettersMessageMessage
from huaweicloudsdkdms.v2.model.consume_deadletters_message_request import ConsumeDeadlettersMessageRequest
from huaweicloudsdkdms.v2.model.consume_deadletters_message_response import ConsumeDeadlettersMessageResponse
from huaweicloudsdkdms.v2.model.consume_message import ConsumeMessage
from huaweicloudsdkdms.v2.model.consume_message_message import ConsumeMessageMessage
from huaweicloudsdkdms.v2.model.consume_messages_request import ConsumeMessagesRequest
from huaweicloudsdkdms.v2.model.consume_messages_response import ConsumeMessagesResponse
from huaweicloudsdkdms.v2.model.create_consumer_group_req import CreateConsumerGroupReq
from huaweicloudsdkdms.v2.model.create_consumer_group_request import CreateConsumerGroupRequest
from huaweicloudsdkdms.v2.model.create_consumer_group_resp_groups import CreateConsumerGroupRespGroups
from huaweicloudsdkdms.v2.model.create_consumer_group_response import CreateConsumerGroupResponse
from huaweicloudsdkdms.v2.model.create_queue_req import CreateQueueReq
from huaweicloudsdkdms.v2.model.create_queue_request import CreateQueueRequest
from huaweicloudsdkdms.v2.model.create_queue_response import CreateQueueResponse
from huaweicloudsdkdms.v2.model.delete_queue_request import DeleteQueueRequest
from huaweicloudsdkdms.v2.model.delete_queue_response import DeleteQueueResponse
from huaweicloudsdkdms.v2.model.delete_specified_consumer_group_request import DeleteSpecifiedConsumerGroupRequest
from huaweicloudsdkdms.v2.model.delete_specified_consumer_group_response import DeleteSpecifiedConsumerGroupResponse
from huaweicloudsdkdms.v2.model.group_entity import GroupEntity
from huaweicloudsdkdms.v2.model.list_consumer_groups_request import ListConsumerGroupsRequest
from huaweicloudsdkdms.v2.model.list_consumer_groups_response import ListConsumerGroupsResponse
from huaweicloudsdkdms.v2.model.list_queue_groups_resp_groups import ListQueueGroupsRespGroups
from huaweicloudsdkdms.v2.model.list_queues_request import ListQueuesRequest
from huaweicloudsdkdms.v2.model.list_queues_resp_queues import ListQueuesRespQueues
from huaweicloudsdkdms.v2.model.list_queues_response import ListQueuesResponse
from huaweicloudsdkdms.v2.model.send_message_entity import SendMessageEntity
from huaweicloudsdkdms.v2.model.send_messages_req import SendMessagesReq
from huaweicloudsdkdms.v2.model.send_messages_request import SendMessagesRequest
from huaweicloudsdkdms.v2.model.send_messages_resp_messages import SendMessagesRespMessages
from huaweicloudsdkdms.v2.model.send_messages_response import SendMessagesResponse
from huaweicloudsdkdms.v2.model.show_project_tags_resp_tags import ShowProjectTagsRespTags
from huaweicloudsdkdms.v2.model.show_queue_project_tags_request import ShowQueueProjectTagsRequest
from huaweicloudsdkdms.v2.model.show_queue_project_tags_response import ShowQueueProjectTagsResponse
from huaweicloudsdkdms.v2.model.show_queue_request import ShowQueueRequest
from huaweicloudsdkdms.v2.model.show_queue_response import ShowQueueResponse
from huaweicloudsdkdms.v2.model.show_queue_tags_request import ShowQueueTagsRequest
from huaweicloudsdkdms.v2.model.show_queue_tags_response import ShowQueueTagsResponse
from huaweicloudsdkdms.v2.model.show_quotas_request import ShowQuotasRequest
from huaweicloudsdkdms.v2.model.show_quotas_resp_quotas import ShowQuotasRespQuotas
from huaweicloudsdkdms.v2.model.show_quotas_resp_quotas_resources import ShowQuotasRespQuotasResources
from huaweicloudsdkdms.v2.model.show_quotas_response import ShowQuotasResponse

==> huaweicloudsdkdms-3.0.104-py2.py3-none-any.whl: huaweicloudsdkdms/v2/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

# import DmsClient
from huaweicloudsdkdms.v2.dms_client import DmsClient
from huaweicloudsdkdms.v2.dms_async_client import DmsAsyncClient
# import models into sdk package
from huaweicloudsdkdms.v2.model.batch_create_or_delete_queue_tag_request import BatchCreateOrDeleteQueueTagRequest
from huaweicloudsdkdms.v2.model.batch_create_or_delete_queue_tag_response import BatchCreateOrDeleteQueueTagResponse
from huaweicloudsdkdms.v2.model.batch_create_or_delete_tag_req import BatchCreateOrDeleteTagReq
from huaweicloudsdkdms.v2.model.batch_create_or_delete_tag_req_tags import BatchCreateOrDeleteTagReqTags
from huaweicloudsdkdms.v2.model.confirm_consumption_messages_req import ConfirmConsumptionMessagesReq
from huaweicloudsdkdms.v2.model.confirm_consumption_messages_request import ConfirmConsumptionMessagesRequest
from huaweicloudsdkdms.v2.model.confirm_consumption_messages_response import ConfirmConsumptionMessagesResponse
from huaweicloudsdkdms.v2.model.confirm_dead_letters_messages_req import ConfirmDeadLettersMessagesReq
from huaweicloudsdkdms.v2.model.confirm_dead_letters_messages_request import ConfirmDeadLettersMessagesRequest
from huaweicloudsdkdms.v2.model.confirm_dead_letters_messages_response import ConfirmDeadLettersMessagesResponse
from huaweicloudsdkdms.v2.model.confirm_message_entity import ConfirmMessageEntity
from huaweicloudsdkdms.v2.model.consume_deadletters_message import ConsumeDeadlettersMessage
from huaweicloudsdkdms.v2.model.consume_deadletters_message_message import ConsumeDeadlettersMessageMessage
from huaweicloudsdkdms.v2.model.consume_deadletters_message_request import ConsumeDeadlettersMessageRequest
from huaweicloudsdkdms.v2.model.consume_deadletters_message_response import ConsumeDeadlettersMessageResponse
from huaweicloudsdkdms.v2.model.consume_message import ConsumeMessage
from huaweicloudsdkdms.v2.model.consume_message_message import ConsumeMessageMessage
from huaweicloudsdkdms.v2.model.consume_messages_request import ConsumeMessagesRequest
from huaweicloudsdkdms.v2.model.consume_messages_response import ConsumeMessagesResponse
from huaweicloudsdkdms.v2.model.create_consumer_group_req import CreateConsumerGroupReq
from huaweicloudsdkdms.v2.model.create_consumer_group_request import CreateConsumerGroupRequest
from huaweicloudsdkdms.v2.model.create_consumer_group_resp_groups import CreateConsumerGroupRespGroups
from huaweicloudsdkdms.v2.model.create_consumer_group_response import CreateConsumerGroupResponse
from huaweicloudsdkdms.v2.model.create_queue_req import CreateQueueReq
from huaweicloudsdkdms.v2.model.create_queue_request import CreateQueueRequest
from huaweicloudsdkdms.v2.model.create_queue_response import CreateQueueResponse
from huaweicloudsdkdms.v2.model.delete_queue_request import DeleteQueueRequest
from huaweicloudsdkdms.v2.model.delete_queue_response import DeleteQueueResponse
from huaweicloudsdkdms.v2.model.delete_specified_consumer_group_request import DeleteSpecifiedConsumerGroupRequest
from huaweicloudsdkdms.v2.model.delete_specified_consumer_group_response import DeleteSpecifiedConsumerGroupResponse
from huaweicloudsdkdms.v2.model.group_entity import GroupEntity
from huaweicloudsdkdms.v2.model.list_consumer_groups_request import ListConsumerGroupsRequest
from huaweicloudsdkdms.v2.model.list_consumer_groups_response import ListConsumerGroupsResponse
from huaweicloudsdkdms.v2.model.list_queue_groups_resp_groups import ListQueueGroupsRespGroups
from huaweicloudsdkdms.v2.model.list_queues_request import ListQueuesRequest
from huaweicloudsdkdms.v2.model.list_queues_resp_queues import ListQueuesRespQueues
from huaweicloudsdkdms.v2.model.list_queues_response import ListQueuesResponse
from huaweicloudsdkdms.v2.model.send_message_entity import SendMessageEntity
from huaweicloudsdkdms.v2.model.send_messages_req import SendMessagesReq
from huaweicloudsdkdms.v2.model.send_messages_request import SendMessagesRequest
from huaweicloudsdkdms.v2.model.send_messages_resp_messages import SendMessagesRespMessages
from huaweicloudsdkdms.v2.model.send_messages_response import SendMessagesResponse
from huaweicloudsdkdms.v2.model.show_project_tags_resp_tags import ShowProjectTagsRespTags
from huaweicloudsdkdms.v2.model.show_queue_project_tags_request import ShowQueueProjectTagsRequest
from huaweicloudsdkdms.v2.model.show_queue_project_tags_response import ShowQueueProjectTagsResponse
from huaweicloudsdkdms.v2.model.show_queue_request import ShowQueueRequest
from huaweicloudsdkdms.v2.model.show_queue_response import ShowQueueResponse
from huaweicloudsdkdms.v2.model.show_queue_tags_request import ShowQueueTagsRequest
from huaweicloudsdkdms.v2.model.show_queue_tags_response import ShowQueueTagsResponse
from huaweicloudsdkdms.v2.model.show_quotas_request import ShowQuotasRequest
from huaweicloudsdkdms.v2.model.show_quotas_resp_quotas import ShowQuotasRespQuotas
from huaweicloudsdkdms.v2.model.show_quotas_resp_quotas_resources import ShowQuotasRespQuotasResources
from huaweicloudsdkdms.v2.model.show_quotas_response import ShowQuotasResponse
